/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package sync4j.framework.engine.pipeline;

import java.io.Serializable;
import java.util.HashMap;

/**
 * This class allows at the elements of the pipeline to add their property
 * independently regarding the other elements.
 * <p>
 * Standard properties are:
 * <ul>
 *   sync4j.sessionid - the server session id
 * </ul>
 * <p>
 * <b>NOTE:</b> the prefix <i>sync4j.</i> for property keys is reserved for
 * Sync4j internal use.
 *
 * @version $Id: MessageProcessingContext.java,v 1.5.4.1 2005/01/20 16:09:22 luigiafassina Exp $
 */
public class MessageProcessingContext implements Serializable {

    // --------------------------------------------------------------- Constants
    public static final String PROPERTY_SESSIONID = "sync4j.sessionid";
    
    // ------------------------------------------------------------ Private data
    private HashMap properties = new HashMap();
    
    // ------------------------------------------------------------ Constructors

    // -------------------------------------------------------------- Properties

    /**
     * Getter for properties
     * @return Value of properties
     */
    public HashMap getProperties() {
        return this.properties;
    }

    /**
     * Setter for properties.
     * @param property New value of properties.
     */
    public void setProperty(HashMap properties) {
        this.properties = properties;
    }

    // ---------------------------------------------------------- Public methods
    
    /**
     * Returns the value of the property associated to the given key
     *
     * @param key the context property key
     *
     * @return the property value or null if key was not found
     */
    public Object getProperty(String key) {
        return properties.get(key);
    }

    /**
     * Sets a given context property
     *
     * @param key the context property key
     * @param value the context property value
     *
     */
    public void setProperty(String key, Object value) {
        properties.put(key, value);
    }

}