/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.framework.server;

import java.io.Serializable;

/**
 * This class represents the device capabilities.
 *
 * @author  Luigia Fassina @ Funambol
 *
 * @version $Id: Capabilities.java,v 1.4.2.2 2005/01/27 12:02:21 luigiafassina Exp $
 *
 */
public class Capabilities implements Serializable {

    // ------------------------------------------------------------ Private data
    private String  id                    ;
    private boolean supportLargeObject    ;
    private boolean supportNumberOfChanges;

    // ------------------------------------------------------------- Costructors
    /** Creates a new instance of Capabilities */
    public Capabilities() {
        this(null, false, false);
    }

    /**
     * Creates a new instance of Capabilities.
     *
     * @param id the capabilities id
     */
    public Capabilities(String id) {
        this(id, false, false);
    }

    /**
     * Creates a new instance of Capabilities.
     *
     * @param id the capabilities id
     * @param largeobject Y if the client device supports large objects,
     *                    N otherwise
     * @param numberofchanges Y if the client device supports number of changes,
     *                        N otherwise
     *
     */
    public Capabilities(String  id                    ,
                        boolean supportLargeObject    ,
                        boolean supportNumberOfChanges) {

        this.id                     = id                    ;
        this.supportLargeObject     = supportLargeObject    ;
        this.supportNumberOfChanges = supportNumberOfChanges;
    }

    /**
     * Getter for property id.
     * @return Value of property id.
     */
    public String getId() {
        return id;
    }

    /**
     * Setter for property id.
     * @param name New value of property id.
     */
    public void setId(String id) {
        this.id = id;
    }

    /**
     * Setter for property supportLargeObject.
     * @param name New value of property supportLargeObject.
     *
     */
    public void setSupportLargeObject(boolean supportLargeObject) {
        this.supportLargeObject = supportLargeObject;
    }

    /**
     * Getter for property supportLargeObject.
     * @return true if device support large obj.
     */
    public boolean isSupportLargeObject() {
        return supportLargeObject;
    }

    /** Setter for property numberOfChanges.
     * @param name New value of property numberOfChanges.
     *
     */
    public void setSupportNumberOfChanges(boolean supportNumberOfChanges) {
        this.supportNumberOfChanges = supportNumberOfChanges;
    }

    /**
     * Getter for property supportNumberOfChanges.
     * @return true if device support number of changes.
     */
    public boolean isSupportNumberOfChanges() {
        return supportNumberOfChanges;
    }

}
